"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rxjs_1 = require("rxjs");
var javascriptutilities_1 = require("javascriptutilities");
var type_safe_state_js_1 = require("type-safe-state-js");
var Utils = require("./util");
/**
 * Act as a centralized storage for state. This store can dispatch actions that
 * will be reduced onto the existing state.
 * @implements {Type} Type implementation.
 */
var Self = /** @class */ (function () {
    function Self() {
        var _this = this;
        this.initialize = function (reducer) {
            _this.action.asObservable()
                .mapNonNilOrEmpty(function (v) { return v; })
                .scan(function (acc, action) { return reducer(acc, action); }, _this.state.value)
                .subscribe(_this.state)
                .toBeDisposedBy(_this.subscription);
        };
        this.deinitialize = function () {
            _this.subscription.unsubscribe();
        };
        this.dispatch = function (action) {
            _this.actionTrigger().next(action);
        };
        this.actionTrigger = function () {
            return _this.action;
        };
        this.actionStream = function () {
            return _this.action.asObservable().mapNonNilOrEmpty(function (v) { return v; });
        };
        this.stateStream = function () { return _this.state; };
        this.valueAtNode = function (id) {
            return Utils.valueAtNode(_this.state, id);
        };
        this.stringAtNode = function (id) {
            return Utils.stringAtNode(_this.state, id);
        };
        this.numberAtNode = function (id) {
            return Utils.numberAtNode(_this.state, id);
        };
        this.booleanAtNode = function (id) {
            return Utils.booleanAtNode(_this.state, id);
        };
        this.action = new javascriptutilities_1.IncompletableSubject(new rxjs_1.BehaviorSubject(undefined));
        this.state = new rxjs_1.BehaviorSubject(type_safe_state_js_1.State.empty());
        this.subscription = new rxjs_1.Subscription();
    }
    Self.prototype.instanceAtNode = function (ctor, id) {
        return Utils.instanceAtNode(this.state, ctor, id);
    };
    return Self;
}());
exports.Self = Self;
/**
 * Create and initialize a dispatch store.
 * @param {Reducer<any>} reducer A Reducer instance.
 * @returns {Self} A dispatch store instance.
 */
exports.createDefault = function (reducer) {
    var store = new Self();
    store.initialize(reducer);
    return store;
};
//# sourceMappingURL=DispatchStore.js.map