import { Observable } from 'rxjs';
import { Try } from 'javascriptutilities';
import { State } from 'type-safe-state-js';
export declare type STStream = Observable<State.Self<any>>;
/**
 * Stream the value at a node.
 * @param {STStream} The state stream.
 * @param {string} id A string value.
 * @returns {Observable<Try<any>>} An Observable instance.
 */
export declare let valueAtNode: (stream: Observable<State.Self<any>>, id: string) => Observable<Try<any>>;
/**
 * Convenience method to stream a string from a node.
 * @param {STStream} The state stream.
 * @param {string} id A string value.
 * @returns {Observable<Try<string>>} An Observable instance.
 */
export declare let stringAtNode: (stream: Observable<State.Self<any>>, id: string) => Observable<Try<string>>;
/**
 * Convenience method to stream a number from a node.
 * @param {STStream} The state stream.
 * @param {string} id A string value.
 * @returns {Observable<Try<number>>} An Observable instance.
 */
export declare let numberAtNode: (stream: Observable<State.Self<any>>, id: string) => Observable<Try<number>>;
/**
 * Convenience method to stream a boolean from a node.
 * @param {STStream} The state stream.
 * @param {string} id A string value.
 * @returns {Observable<Try<boolean>>} An Observable instance.
 */
export declare let booleanAtNode: (stream: Observable<State.Self<any>>, id: string) => Observable<Try<boolean>>;
/**
 * Convenience method to stream R from a node.
 * @template R Generics parameter.
 * @param {STStream} The state stream.
 * @param {new () => R} ctor Constructor function.
 * @param {string} id A string value.
 * @returns {Observable<Try<R>>} An Observable instance.
 */
export declare function instanceAtNode<R>(stream: STStream, ctor: new () => R, id: string): Observable<Try<R>>;
